package com.clx.clx_map_poi_search

import android.content.Context
import android.util.Log
import com.amap.api.services.core.LatLonPoint
import com.amap.api.services.core.PoiItem
import com.amap.api.services.poisearch.PoiResult
import com.amap.api.services.poisearch.PoiSearch

class ClxMapPoiSearchImpl : PoiSearch.OnPoiSearchListener, IPoiSearch {

    /**
     * 通过关键字搜索poi
     */
    override fun onSearchKeywords(context: Context?, keywords: String?) {
        Log.d(Constants.TAG, "onSearchKeywords: keywords = $keywords")
        val query = PoiSearch.Query(keywords, Constants.SEARCH_CONTENT, "")
        query.pageNum = 1
        query.pageSize = 50
        val poiSearch = PoiSearch(context, query)
        poiSearch.setOnPoiSearchListener(this)
        poiSearch.searchPOIAsyn()
    }

    /**
     * 通过经纬度搜索poi
     */
    override fun onSearchAround(context: Context?, latitude: Double?, longitude: Double?) {
        Log.d(Constants.TAG, "onSearchAround: latitude = $latitude, longitude = $longitude")
        val query = PoiSearch.Query("", Constants.SEARCH_CONTENT, "")
        query.pageNum = 1
        query.pageSize = 50
        val poiSearch = PoiSearch(context, query)
        poiSearch.bound =
            PoiSearch.SearchBound(LatLonPoint(latitude ?: 0.0, longitude ?: 0.0), 1000)
        poiSearch.setOnPoiSearchListener(this)
        poiSearch.searchPOIAsyn()
    }

    /**
     * 根据 关键字、经纬度、城市搜索poi
     */
    override fun onSearchAroundAll(
        context: Context?,
        keywords: String?,
        latitude: Double?,
        longitude: Double?,
        city: String?,
    ) {
        Log.d(
            Constants.TAG,
            "onSearchAroundAll: keywords = $keywords latitude = $latitude, longitude = $longitude city = $city"
        )
        val query = PoiSearch.Query(keywords, Constants.SEARCH_CONTENT, city)
        query.pageNum = 1
        query.pageSize = 50
        val poiSearch = PoiSearch(context, query)
        if (latitude != null && longitude != null) {
            poiSearch.bound =
                PoiSearch.SearchBound(LatLonPoint(latitude ?: 0.0, longitude ?: 0.0), 1000)
        }
        poiSearch.setOnPoiSearchListener(this)
        poiSearch.searchPOIAsyn()
    }


    /**===============================PoiSearch回调================================**/

    override fun onPoiSearched(poiResult: PoiResult, code: Int) {
        val arguments: MutableMap<String, Any> = HashMap(2)
        Log.d(Constants.TAG, "onPoiSearched: code = $code poiList size ${poiResult.pois.size}")
        val list = Utils.buildSearchResultList(poiResult, code)
        val data: MutableMap<String, Any> = HashMap()
        data["poiList"] = list
        arguments["searchPOIResult"] = data
        Log.d(Constants.TAG, "onPoiSearched: arguments = $arguments")
        listener?.onPoiResult(arguments)
    }

    override fun onPoiItemSearched(poiItem: PoiItem, p1: Int) {
        Log.d(Constants.TAG, "onPoiItemSearched: poiItem = $poiItem")
    }

    /**===============================poi搜索结果listener================================**/

    private var listener: OnPoiSearchedResult? = null

    fun setOnPoiSearchedResult(listener: OnPoiSearchedResult?) {
        this.listener = listener
    }

    interface OnPoiSearchedResult {
        fun onPoiResult(data: Map<String, Any>)
    }
}