package com.clx.clx_map_poi_search

import android.content.Context
import android.util.Log
import androidx.annotation.NonNull
import com.amap.api.services.core.ServiceSettings
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result

/** ClxMapPoiSearchPlugin */
class ClxMapPoiSearchPlugin : FlutterPlugin, MethodCallHandler,
    ClxMapPoiSearchImpl.OnPoiSearchedResult {
    private var mContext: Context? = null
    private lateinit var channel: MethodChannel
    private var mResult: Result? = null
    private var mMapPoiSearchImpl: ClxMapPoiSearchImpl? = null


    override fun onAttachedToEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
        channel = MethodChannel(binding.binaryMessenger, "clx_map_poi_search")
        channel.setMethodCallHandler(this)
        mContext = binding.applicationContext
        mMapPoiSearchImpl = ClxMapPoiSearchImpl()
        mMapPoiSearchImpl?.setOnPoiSearchedResult(this)

        //更新隐私合规状态,需要在初始化搜索之前完成
        ServiceSettings.updatePrivacyShow(mContext, true, true)
        //更新同意隐私状态,需要在初始化地图之前完成
        ServiceSettings.updatePrivacyAgree(mContext, true)
    }

    override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
        this.mResult = result
        Log.d(Constants.TAG, "onMethodCall: method = ${call.method} argument = ${call.arguments}")
        val keywords = call.argument<String?>("keywords")
        val latitude = call.argument<Double?>("latitude")
        val longitude = call.argument<Double?>("longitude")
        val city = call.argument<String?>("city")
        when (call.method) {
            "searchPOI#initPoiSearch" -> {

            }
            "searchPOI#keywords" -> mMapPoiSearchImpl?.onSearchKeywords(
                mContext,
                keywords
            )

            "searchPOI#around" -> mMapPoiSearchImpl?.onSearchAround(
                mContext,
                latitude,
                longitude
            )
            "searchPOI#aroundAll" -> mMapPoiSearchImpl?.onSearchAroundAll(
                mContext,
                keywords,
                latitude,
                longitude,
                city
            )
            else -> result.notImplemented()
        }
    }

    override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
        channel.setMethodCallHandler(null)
        mContext = null
        mResult = null
        mMapPoiSearchImpl = null
    }

    /**
     * 搜索结果回调
     */
    override fun onPoiResult(data: Map<String, Any>) {
        mResult?.success(data)
    }

}
