package com.clx.clx_map_poi_search

import android.util.Log
import com.amap.api.services.poisearch.PoiResult
import com.amap.api.services.core.AMapException
import com.amap.api.services.core.PoiItem
import com.amap.api.services.help.Tip
import com.amap.api.services.geocoder.RegeocodeResult
import com.amap.api.services.geocoder.RegeocodeAddress
import java.util.ArrayList
import java.util.HashMap

/**
 * @Author : shixiaochen
 * @Time : 2022/4/15
 * @Description :
 */
object Utils {
    /**
     * poi搜索 数据
     *
     * @param poiResult poiResult
     * @param code      响应码
     * @return 返回数据
     */
    fun buildSearchResultList(poiResult: PoiResult, code: Int): List<Map<String, Any>> {
        val result: MutableList<Map<String, Any>> = ArrayList()
        if (code == AMapException.CODE_AMAP_SUCCESS) {
            val list = poiResult.pois
            Log.d(Constants.TAG, "buildSearchResultList: list = $list")
            if (list != null) {
                for (poiItem in list) {
                    val map = HashMap<String, Any>()
                    map["latitude"] = poiItem.latLonPoint.latitude
                    map["longitude"] = poiItem.latLonPoint.longitude
                    map["provinceName"] = poiItem.provinceName
                    map["provinceCode"] = poiItem.provinceCode
                    map["cityName"] = poiItem.cityName
                    map["cityCode"] = poiItem.cityCode
                    map["adName"] = poiItem.adName
                    map["businessArea"] = poiItem.businessArea
                    map["snippet"] = poiItem.snippet
                    map["title"] = poiItem.title
                    map["distance"] = poiItem.distance
                    result.add(map)
                }
            }
        }
        return result
    }

    /**
     * inputTips 数据
     *
     * @param list tips
     * @param code 响应码
     * @return 返回数据
     */
    fun buildSearchInputResultList(list: List<Tip>?, code: Int): List<Map<String, Any?>> {
        val result: MutableList<Map<String, Any?>> = ArrayList()
        if (code == AMapException.CODE_AMAP_SUCCESS) {
            Log.d("TAG", "buildSearchResultList: list = $list")
            if (list != null) {
                for (tip in list) {
                    val map = HashMap<String, Any?>()
                    map["name"] = tip.name
                    map["address"] = tip.address
                    map["adCode"] = tip.adcode
                    map["district"] = tip.district
                    map["poiID"] = tip.poiID
                    map["typeCode"] = tip.typeCode
                    if (tip.point != null) {
                        map["latitude"] = tip.point.latitude
                        map["longitude"] = tip.point.longitude
                    } else {
                        map["latitude"] = null
                        map["longitude"] = null
                    }
                    result.add(map)
                }
            }
        }
        return result
    }

    /**
     * SearchRegeocode
     *
     * @param regeocode regeocode
     * @param code      响应码
     * @return 返回数据
     */
    fun buildSearchRegeocodeResultList(regeocode: RegeocodeResult?, code: Int): Map<String, Any> {
        val result: MutableMap<String, Any> = HashMap()
        if (code == AMapException.CODE_AMAP_SUCCESS) {
            if (regeocode != null && regeocode.regeocodeAddress != null) {
                val address = regeocode.regeocodeAddress
                result["province"] = address.province
                result["city"] = address.city
                result["town"] = address.township
                result["street"] = address.building
                result["district"] = address.district
                result["address"] = address.formatAddress
                result["adCode"] = address.adCode
                result["cityCode"] = address.cityCode
                result["country"] = address.country
                result["neighborhood"] = address.neighborhood
                result["townCode"] = address.towncode
            }
        }
        return result
    }
}