import 'package:amap_flutter_base/amap_flutter_base.dart';
import 'package:clx_map_poi_search/core/clx_map_poi_search_platform_interface.dart';
import 'package:clx_map_poi_search/core/poi_result.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';

/// An implementation of [ClxMapPoiSearchPlatform] that uses method channels.
class MethodChannelClxMapPoiSearch extends ClxMapPoiSearchPlatform {
  /// The method channel used to interact with the native platform.
  @visibleForTesting
  final methodChannel = const MethodChannel('clx_map_poi_search');

  @override
  MethodChannel getSearchChannel() {
    return methodChannel;
  }

  @override
  Future<void> initPoiSearch(AMapApiKey apiKey) async {
    await methodChannel.invokeMethod<dynamic>('searchPOI#initPoiSearch', <String, dynamic>{
      'apiKey': apiKey.toMap(),
    });
  }

  // 关键字搜索
  @override
  Future<PoiResult?> keywordsSearch(String keywords) async {
    var searchPOIResult = await methodChannel.invokeMethod<dynamic>('searchPOI#keywords', <String, dynamic>{
      'keywords': keywords,
    });
    return PoiResult.toPoiResult(searchPOIResult["searchPOIResult"]);
  }

  /// 根据经纬度搜索
  @override
  Future<PoiResult?> aroundSearch(double latitude, double longitude) async {
    var searchPOIResult = await methodChannel.invokeMethod<dynamic>('searchPOI#around', <String, dynamic>{
      'latitude': latitude,
      'longitude': longitude,
    });
    return PoiResult.toPoiResult(searchPOIResult["searchPOIResult"]);
  }

  /// 周边搜索
  @override
  Future<PoiResult?> aroundSearchAll(String keywords, { double? latitude, double? longitude, String? city }) async {
    var searchPOIResult = await methodChannel.invokeMethod<dynamic>('searchPOI#aroundAll', <String, dynamic>{
      'keywords': keywords,
      'latitude': latitude,
      'longitude': longitude,
      'city': city,
    });
    return PoiResult.toPoiResult(searchPOIResult["searchPOIResult"]);
  }

  /// 两点间的直线距离计算
  @override
  Future<double?> getDistanceBetweenMapPoints(List<double?> pointF, List<double?> pointT,) async {
    var searchPOIResult = await methodChannel.invokeMethod<dynamic>('searchPOI#getDistance', <String, dynamic>{
      'pointF': pointF,
      'pointT': pointT,
    });
    return searchPOIResult;
  }

}
