import 'package:amap_flutter_base/amap_flutter_base.dart';
import 'package:clx_map_poi_search/core/clx_map_poi_search_method_channel.dart';
import 'package:clx_map_poi_search/core/poi_result.dart';
import 'package:flutter/services.dart';
import 'package:plugin_platform_interface/plugin_platform_interface.dart';

abstract class ClxMapPoiSearchPlatform extends PlatformInterface {
  /// Constructs a ClxMapPoiSearchPlatform.
  ClxMapPoiSearchPlatform() : super(token: _token);

  static final Object _token = Object();

  static ClxMapPoiSearchPlatform _instance = MethodChannelClxMapPoiSearch();

  /// 高德开放平台的key
  //AMapApiKey? apiKey;

  /// The default instance of [ClxMapPoiSearchPlatform] to use.
  ///
  /// Defaults to [MethodChannelClxMapPoiSearch].
  static ClxMapPoiSearchPlatform get instance => _instance;
  
  /// Platform-specific implementations should set this with their own
  /// platform-specific class that extends [ClxMapPoiSearchPlatform] when
  /// they register themselves.
  static set instance(ClxMapPoiSearchPlatform instance) {
    PlatformInterface.verifyToken(instance, _token);
    _instance = instance;
  }

  // 获取当前的channel
  MethodChannel getSearchChannel() {
    throw UnimplementedError('searchChannel() has not been implemented.');
  }

  // 初始化搜索
  Future<void> initPoiSearch(AMapApiKey apiKey) {
    throw UnimplementedError('initPoiSearch() has not been implemented.');
  }

  // 关键字搜索
  Future<PoiResult?> keywordsSearch(String keywords) async {
    throw UnimplementedError('keywordsSearch() has not been implemented.');
  }

  // 周边搜索
  Future<PoiResult?> aroundSearch(double latitude, double longitude) async {
    throw UnimplementedError('aroundSearch() has not been implemented.');
  }

  /// 周边搜索
  Future<PoiResult?> aroundSearchAll(String keywords, { double? latitude, double? longitude, String? city, }) async {
    throw UnimplementedError('aroundSearchAll() has not been implemented.');
  }

  /// 两点间的直线距离计算
  Future<double?> getDistanceBetweenMapPoints(
    List<double?> pointF,
    List<double?> pointT,
  ) {
    throw UnimplementedError('getDistanceBetweenMapPoints() has not been implemented.');
  }
}
